<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Microsoft.Graphics.DirectX

Windows Runtime (WinRT) APIs for for the `Microsoft.Graphics.DirectX` namespace.

This package provides the `winrt.microsoft.graphics.directx` module.
